@@ -30,15 +30,20 @@
 
 #include <QMessageBox>
 #include <QPushButton>
-
+#include <QDir>
 #include <QUrl>
 #include <QProcess>
 #include <recent-vfs-manager.h>
+#include <QApplication>
 
 #include <QDebug>
+#include <QtX11Extras/QX11Info>
+#include <kstartupinfo.h>
 
 using namespace Peony;
 
+#define USE_STARTUP_INFO true
+
 FileLaunchAction::FileLaunchAction(const QString &uri, GAppInfo *app_info, bool forceWithArg, QObject *parent) : QAction(parent)
 {
     m_uri = uri;
@@ -48,11 +53,16 @@ FileLaunchAction::FileLaunchAction(const QString &uri, GAppInfo *app_info, bool
     if (!isValid())
         return;
 
-    GThemedIcon *icon = G_THEMED_ICON(g_app_info_get_icon(m_app_info));
-    const char * const * icon_names = g_themed_icon_get_names(icon);
+    GIcon *icon = g_app_info_get_icon(m_app_info);
+    const char * const * icon_names = g_themed_icon_get_names(G_THEMED_ICON (icon));
 
-    if (icon_names)
+    if (icon_names) {
         m_icon = QIcon::fromTheme(*icon_names);
+    } else {
+        // fix #68592
+        g_autofree gchar *icon_path = g_icon_to_string(icon);
+        m_icon.addFile(icon_path);
+    }
     setIcon(m_icon);
     m_info_name = g_app_info_get_name(m_app_info);
     setText(m_info_name);
@@ -192,6 +202,22 @@ void FileLaunchAction::lauchFileSync(bool forceWithArg, bool skipDialog)
     }
 }
 
+#if USE_STARTUP_INFO
+void pid_callback(GDesktopAppInfo *appinfo, GPid pid, gpointer user_data) {
+    KStartupInfoId* startInfoId = static_cast<KStartupInfoId*>(user_data);
+    if (!startInfoId)
+        return;
+
+    KStartupInfoData data;
+    data.addPid(pid);
+    data.setIconGeometry(QRect(0, 0, 1, 1));  // ugly
+
+    KStartupInfo::sendChange(*startInfoId, data);
+    KStartupInfo::resetStartupEnv();
+    delete startInfoId;
+}
+#endif
+
 void FileLaunchAction::lauchFileAsync(bool forceWithArg, bool skipDialog)
 {
     //FIXME: replace BLOCKING api in ui thread.
@@ -205,9 +231,10 @@ void FileLaunchAction::lauchFileAsync(bool forceWithArg, bool skipDialog)
     bool isAppImage = fileInfo->type() == "application/vnd.appimage";
     bool isExecutable = isExcuteableFile(fileInfo->type());
     qDebug() <<"executable:" <<executable <<isAppImage <<fileInfo->type();
+
+    QUrl url = m_uri;
     if (isAppImage) {
         if (executable) {
-            QUrl url = m_uri;
             auto path = url.path();
 
             QProcess p;
@@ -263,7 +290,7 @@ void FileLaunchAction::lauchFileAsync(bool forceWithArg, bool skipDialog)
             }
             else
                 QMessageBox::critical(nullptr, tr("Open Failed"),
-                                  tr("Can not open %1, Please confirm you have the right authority.").arg(m_uri));
+                                  tr("Can not open %1, Please confirm you have the right authority.").arg(url.toDisplayString()));
         }
         else if (fileInfo->isDesktopFile())
         {
@@ -278,7 +305,8 @@ void FileLaunchAction::lauchFileAsync(bool forceWithArg, bool skipDialog)
             }
         }
         else {
-            auto result = QMessageBox::question(nullptr, tr("Error"), tr("Can not get a default application for opening %1, do you want open it with text format?").arg(m_uri));
+            auto result = QMessageBox::question(nullptr, tr("Error"),
+                                                tr("Can not get a default application for opening %1, do you want open it with text format?").arg(url.toDisplayString()));
             if (result == QMessageBox::Yes) {
                 GAppInfo *text_info = g_app_info_get_default_for_type("text/plain", false);
                 GList *l = nullptr;
@@ -298,8 +326,31 @@ void FileLaunchAction::lauchFileAsync(bool forceWithArg, bool skipDialog)
         return;
     }
 
+#if USE_STARTUP_INFO
+    // send startup info to kwindowsystem
+    bool needCleanStartInfoId = true;
+    quint32 timeStamp = QX11Info::isPlatformX11() ? QX11Info::appUserTime() : 0;
+    KStartupInfoId* startInfoId = new KStartupInfoId();
+    startInfoId->initId(KStartupInfo::createNewStartupIdForTimestamp(timeStamp));
+    startInfoId->setupStartupEnv();
+    KStartupInfoData data;
+    data.setHostname();
+    float scale = qApp->devicePixelRatio();
+    QRect rect = fileInfo.get()->property("iconGeometry").toRect();
+    rect.moveTo(rect.x() * scale, rect.y() * scale);
+    if (rect.isValid())
+        data.setIconGeometry(rect);
+    data.setLaunchedBy(getpid());
+
+    KStartupInfo::sendStartup(*startInfoId, data);
+#endif
+
     if (isDesktopFileAction() && !forceWithArg) {
-#if GLIB_CHECK_VERSION(2, 60, 0)
+#if USE_STARTUP_INFO
+        needCleanStartInfoId = !g_desktop_app_info_launch_uris_as_manager(G_DESKTOP_APP_INFO(m_app_info), nullptr, nullptr,
+                                                  GSpawnFlags::G_SPAWN_DEFAULT, nullptr, nullptr,
+                                                  pid_callback, (gpointer)startInfoId, nullptr);
+#elif GLIB_CHECK_VERSION(2, 60, 0)
         g_app_info_launch_uris_async(m_app_info, nullptr,
                                      nullptr, nullptr,
                                      nullptr, nullptr);
@@ -310,7 +361,12 @@ void FileLaunchAction::lauchFileAsync(bool forceWithArg, bool skipDialog)
         GList *l = nullptr;
         char *uri = g_strdup(m_uri.toUtf8().constData());
         l = g_list_prepend(l, uri);
-#if GLIB_CHECK_VERSION(2, 60, 0)
+#if USE_STARTUP_INFO
+        needCleanStartInfoId = !g_desktop_app_info_launch_uris_as_manager(G_DESKTOP_APP_INFO(m_app_info), l, nullptr, 
+                                                  GSpawnFlags::G_SPAWN_DEFAULT, nullptr, nullptr, 
+                                                  pid_callback, (gpointer)startInfoId, nullptr);
+        RecentVFSManager::getInstance()->insert(fileInfo.get()->uri(), fileInfo.get()->mimeType(), fileInfo.get()->displayName(), g_app_info_get_name(m_app_info));
+#elif GLIB_CHECK_VERSION(2, 60, 0)
         g_app_info_launch_uris_async(m_app_info, l,
                                      nullptr, nullptr,
                                      nullptr, nullptr);
@@ -320,6 +376,10 @@ void FileLaunchAction::lauchFileAsync(bool forceWithArg, bool skipDialog)
         g_app_info_launch_uris(m_app_info, l, nullptr, nullptr);
 #endif
         g_list_free_full(l, g_free);
+#if USE_STARTUP_INFO
+        if (needCleanStartInfoId && startInfoId)
+            delete startInfoId;
+#endif
     }
 
     return;
@@ -518,8 +578,11 @@ void FileLaunchAction::execFile()
 {
     QUrl url = m_uri;
     char *quote = g_shell_quote(url.path().toUtf8());
+    QString newDir = m_uri.section('/',0,m_uri.count('/')-1);
     GAppInfo *app_info = g_app_info_create_from_commandline(quote, nullptr, G_APP_INFO_CREATE_NONE, nullptr);
+    QDir::setCurrent(QUrl(newDir).path());
     g_app_info_launch(app_info, nullptr, nullptr, nullptr);
+    QDir::setCurrent(QDir::homePath());
     g_object_unref(app_info);
     g_free(quote);
 }
@@ -528,8 +591,11 @@ void FileLaunchAction::execFileInterm()
 {
     QUrl url = m_uri;
     char *quote = g_shell_quote(url.path().toUtf8());
+    QString newDir = m_uri.section('/',0,m_uri.count('/')-1);
     GAppInfo *app_info = g_app_info_create_from_commandline(quote, nullptr, G_APP_INFO_CREATE_NEEDS_TERMINAL, nullptr);
+    QDir::setCurrent(QUrl(newDir).path());
     g_app_info_launch(app_info, nullptr, nullptr, nullptr);
+    QDir::setCurrent(QDir::homePath());
     g_object_unref(app_info);
     g_free(quote);
 }
