@@ -29,70 +29,28 @@
 #include "file-operation-manager.h"
 
 #include <QProcess>
+#include <file-copy.h>
 
 using namespace Peony;
 
-static void handleDuplicate(FileNode *node) {
-    QString name = node->destBaseName();
-    QRegExp regExpNum("^\\(\\d+\\)");
-    QRegExp regExp("\\(\\d+\\)(\\.[0-9a-zA-Z]+|)$");
-    if (name.contains(regExp)) {
-        int num = 0;
-        QString numStr = "";
-
-        QString ext = regExp.cap(0);
-        if (ext.contains(regExpNum)) {
-            numStr = regExpNum.cap(0);
-        }
-
-        numStr.remove(0, 1);
-        numStr.chop(1);
-        num = numStr.toInt();
-        ++num;
-        name = name.replace(regExp, ext.replace(regExpNum, QString("(%1)").arg(num)));
-        node->setDestFileName(name);
-    } else {
-        if (name.contains(".")) {
-            auto list = name.split(".");
-            if (list.count() <= 1) {
-                node->setDestFileName(name+"(1)");
-            } else {
-                int pos = list.count() - 1;
-                if (list.last() == "gz" |
-                        list.last() == "xz" |
-                        list.last() == "Z" |
-                        list.last() == "sit" |
-                        list.last() == "bz" |
-                        list.last() == "bz2") {
-                    pos--;
-                }
-                if (pos < 0)
-                    pos = 0;
-                //list.insert(pos, "(1)");
-                auto tmp = list;
-                QStringList suffixList;
-                for (int i = 0; i < list.count() - pos; i++) {
-                    suffixList.prepend(tmp.takeLast());
-                }
-                auto suffix = suffixList.join(".");
-
-                auto basename = tmp.join(".");
-                name = basename + "(1)" + "." + suffix;
-                if (name.endsWith("."))
-                    name.chop(1);
-                node->setDestFileName(name);
-            }
-        } else {
-            name = name + "(1)";
-            node->setDestFileName(name);
-        }
-    }
+static void handleDuplicate(FileNode *node)
+{
+    node->setDestFileName(FileUtils::handleDuplicateName(node->destBaseName()));
 }
 
 FileMoveOperation::FileMoveOperation(QStringList sourceUris, QString destDirUri, QObject *parent) : FileOperation (parent)
 {
     m_source_uris = sourceUris;
-    m_dest_dir_uri = destDirUri;
+
+    /* favorite://xxx特殊处理,例如本机共享，bug#83353 */
+    if (destDirUri.startsWith("favorite://")) {
+        destDirUri = FileUtils::getTargetUri(destDirUri);
+        if (destDirUri.isEmpty ()) {
+            destDirUri = "favorite:///";
+        }
+    }
+
+    m_dest_dir_uri = FileUtils::urlEncode(destDirUri);
     m_info = std::make_shared<FileOperationInfo>(sourceUris, destDirUri, FileOperationInfo::Move);
 }
 
@@ -105,7 +63,23 @@ FileMoveOperation::~FileMoveOperation()
 void FileMoveOperation::setCopyMove(bool copyMove)
 {
     m_copy_move = copyMove;
-    m_info.get()->m_type = copyMove? FileOperationInfo::Copy: FileOperationInfo::Move;
+}
+
+void FileMoveOperation::setAction(Qt::DropAction action)
+{
+    m_move_action = action;
+    m_info.get()->m_drop_action = action;
+    switch (action) {
+    case Qt::CopyAction: {
+        m_info.get()->m_type = FileOperationInfo::Copy;
+        m_info.get()->m_opposite_type = FileOperationInfo::Delete;
+        break;
+    }
+    default: {
+        m_info.get()->m_type = FileOperationInfo::Move;
+        break;
+    }
+    }
 }
 
 void FileMoveOperation::progress_callback(goffset current_num_bytes,
@@ -118,10 +92,11 @@ void FileMoveOperation::progress_callback(goffset current_num_bytes,
     QUrl url(p_this->m_current_src_uri);
     auto currnet = p_this->m_current_offset + current_num_bytes;
     auto total = p_this->m_total_szie;
-    auto fileIconName = FileUtils::getFileIconName(p_this->m_current_src_uri, false);
+    auto fileIconName = FileUtilsPrivate::getFileIconName(p_this->m_current_src_uri);
     auto destFileName = FileUtils::isFileDirectory(p_this->m_current_dest_dir_uri) ?
                 p_this->m_current_dest_dir_uri + "/" + url.fileName() : p_this->m_current_dest_dir_uri;
 
+//    qDebug() << "move: " << p_this->m_current_src_uri << "  ---  "  << destFileName << currnet << "/" << total << (float(currnet) / total);
     Q_EMIT p_this->FileProgressCallback(p_this->m_current_src_uri, destFileName, fileIconName, currnet, total);
     //format: move srcUri to destDirUri: curent_bytes(count) of total_bytes(count).
 }
@@ -129,6 +104,15 @@ void FileMoveOperation::progress_callback(goffset current_num_bytes,
 ExceptionResponse FileMoveOperation::prehandle(GError *err)
 {
     //setHasError(true);
+
+    /**
+     * @note FIX BUG 79363
+     * 文件传输中拔掉U盘，第一次报错:G_IO_ERROR_FAILED，后续报错:G_IO_ERROR_NOT_FOUND
+     */
+    if (G_IO_ERROR_NOT_FOUND == err->code && m_prehandle_hash.contains(G_IO_ERROR_FAILED)) {
+        return IgnoreAll;
+    }
+
     if (m_prehandle_hash.contains(err->code))
         return m_prehandle_hash.value(err->code);
 
@@ -140,17 +124,113 @@ void FileMoveOperation::move()
     if (isCancelled())
         return;
 
-    QList<FileNode*> nodes;
-    for (auto srcUri : m_source_uris) {
-        //FIXME: ignore the total size when using native move.
-        operationPreparedOne(srcUri, 0);
-        auto node = new FileNode(srcUri, nullptr, nullptr);
-        nodes<<node;
+    // 特殊处理 favorite:///
+    g_autoptr (GFile) destFile = g_file_new_for_uri (m_dest_dir_uri.toUtf8 ().constData ());
+    g_autofree gchar* destSchema = g_file_get_uri_scheme (destFile);
+
+    if (G_IS_FILE (destFile) && destSchema && !g_ascii_strcasecmp (destSchema, "favorite")) {
+        for (auto src : m_source_uris) {
+            g_autoptr (GFile) srcFile = g_file_new_for_uri (src.toUtf8 ().constData ());
+            g_autoptr (GError) error = NULL;
+            // 注意：不可能报冲突错误
+            g_file_move (srcFile, destFile, m_default_copy_flag, getCancellable().get()->get(), GFileProgressCallback (progress_callback), this, &error);
+            if (error) {
+                setHasError ();
+                FileOperationError except;
+                int handle_type = prehandle(error);
+                except.errorType = ET_GIO;
+                except.op = FileOpMove;
+                except.title = tr("Move file error");
+                except.errorCode = error->code;
+                except.errorStr = error->message;
+                except.srcUri = m_current_src_uri;
+                except.destDirUri = m_current_dest_dir_uri;
+                except.isCritical = false;
+                if (handle_type == Other) {
+                    if (G_IO_ERROR_EXISTS != error->code) {
+                        except.dlgType = ED_WARNING;
+                        Q_EMIT errored(except);
+                    }
+                    // ignore multiple bounces
+                    if (except.errorCode == G_IO_ERROR_NOT_SUPPORTED) {
+                        m_prehandle_hash.insert(error->code, IgnoreOne);
+                    }
+                }
+            }
+        }
+
+        Q_EMIT operationFinished();
+
+        return;
     }
+
+    QList<FileNode*> nodes;
+    QList<FileNode*> errNode;
+
+    GError *err = nullptr;
+    m_total_count = m_source_uris.count();
+    auto destDir = wrapGFile(g_file_new_for_uri(m_dest_dir_uri.toUtf8().constData()));
+
+    // file move
+    for (auto srcUri : m_source_uris) {
+        if (isCancelled())
+            return;
+
+        auto node = new FileNode(srcUri, nullptr, nullptr);
+
+        auto srcFile = wrapGFile(g_file_new_for_uri(srcUri.toUtf8().constData()));
+        char *base_name = g_file_get_basename(srcFile.get()->get());
+        auto destFile = wrapGFile(g_file_resolve_relative_path(destDir.get()->get(), base_name));
+        g_autofree char* destUri = g_file_get_uri(destFile.get()->get());
+        node->setDestUri(destUri);
+
+        g_file_move(srcFile.get()->get(),
+                    destFile.get()->get(),
+                    m_default_copy_flag,
+                    getCancellable().get()->get(),
+                    GFileProgressCallback(progress_callback), this, &err);
+        if (err) {
+            errNode << node;
+        } else {
+            node->setState(FileNode::Handled);
+        }
+
+        nodes << node;
+    }
+
+    // file copy-delete
+    goffset *total_size = new goffset(0);
+    for (auto node : errNode) {
+        if (isCancelled())
+            return;
+
+        node->findChildrenRecursively();
+        node->computeTotalSize(total_size);
+    }
+    m_total_szie = *total_size;
+    operationPreparedOne("", m_total_szie);
+    delete total_size;
+
     operationPrepared();
 
-    auto destDir = wrapGFile(g_file_new_for_uri(m_dest_dir_uri.toUtf8().constData()));
-    m_total_count = m_source_uris.count();
+    if (!errNode.isEmpty()) {
+        if (m_move_action == Qt::TargetMoveAction) {
+            m_info.get()->m_type = FileOperationInfo::Move;
+        } else {
+            m_info.get()->m_type = FileOperationInfo::Copy;
+            m_info.get()->m_opposite_type = FileOperationInfo::Delete;
+        }
+    }
+    for (auto node : errNode) {
+        if (isCancelled())
+            return;
+        moveForceUseFallback(node);
+        fileSync(node->uri(), node->destUri());
+    }
+
+    operationStartSnyc();
+
+#if 0
     for (auto file : nodes) {
         if (isCancelled())
             return;
@@ -171,7 +251,7 @@ void FileMoveOperation::move()
         g_free(dest_uri);
         g_free(base_name);
 
-retry:
+//retry:
         GError *err = nullptr;
         g_file_move(srcFile.get()->get(),
                     destFile.get()->get(),
@@ -180,6 +260,11 @@ retry:
                     GFileProgressCallback(progress_callback),
                     this,
                     &err);
+        if (err) {
+            errNode << file;
+        } else {
+            file->setState(FileNode::Handled);
+        }
 
         if (err) {
             setHasError(true);
@@ -195,13 +280,9 @@ retry:
             case G_IO_ERROR_NOT_SUPPORTED:
             case G_IO_ERROR_WOULD_RECURSE:
             case G_IO_ERROR_EXISTS: {
-                setHasError(false);
-                m_force_use_fallback = true;
-                for (auto node : nodes) {
-                    delete node;
-                }
-                nodes.clear();
-                return;
+                moveForceUseFallback(file);
+                operationStartSnyc();
+                continue;
             }
             default:
                 break;
@@ -355,6 +436,7 @@ retry:
         operationProgressedOne(file->uri(), file->destUri(), 0);
         fileSync(file->uri(), file->destUri());
     }
+#endif
     //native move has not clear operation.
     operationProgressed();
 
@@ -567,7 +649,7 @@ fallback_retry:
         auto realDestUri = node->resolveDestFileUri(m_dest_dir_uri);
         destFile = wrapGFile(g_file_new_for_uri(realDestUri.toUtf8().constData()));
         GError *err = nullptr;
-        auto fileIconName = FileUtils::getFileIconName(m_current_src_uri, false);
+        auto fileIconName = FileUtilsPrivate::getFileIconName(m_current_src_uri);
         auto destFileName = FileUtils::isFileDirectory(m_current_dest_dir_uri) ? nullptr : m_current_dest_dir_uri;
         //NOTE: mkdir doesn't have a progress callback.
         Q_EMIT FileProgressCallback(m_current_src_uri, destFileName, fileIconName, node->size(), node->size());
@@ -679,7 +761,7 @@ fallback_retry:
             //node->setState(FileNode::Handled);
         }
 
-        fileIconName = FileUtils::getFileIconName(m_current_src_uri, false);
+        fileIconName = FileUtilsPrivate::getFileIconName(m_current_src_uri);
         destFileName = FileUtils::isFileDirectory(m_current_dest_dir_uri) ? nullptr : m_current_dest_dir_uri;
         //assume that make dir finished anyway
         m_current_offset += node->size();
@@ -693,13 +775,17 @@ fallback_retry:
         GFileWrapperPtr sourceFile = wrapGFile(g_file_new_for_uri(node->uri().toUtf8().constData()));
         auto realDestUri = node->resolveDestFileUri(m_dest_dir_uri);
         destFile = wrapGFile(g_file_new_for_uri(realDestUri.toUtf8().constData()));
-        g_file_copy(sourceFile.get()->get(),
-                    destFile.get()->get(),
-                    m_default_copy_flag,
-                    getCancellable().get()->get(),
-                    GFileProgressCallback(progress_callback),
-                    this,
-                    &err);
+
+        FileCopy fileCopy (node->uri(), realDestUri, m_default_copy_flag,
+                           getCancellable().get()->get(),
+                           GFileProgressCallback(progress_callback),
+                           this,
+                           &err);
+        fileCopy.connect(this, &FileOperation::operationPause, &fileCopy, &FileCopy::pause, Qt::DirectConnection);
+        fileCopy.connect(this, &FileOperation::operationResume, &fileCopy, &FileCopy::resume, Qt::DirectConnection);
+        fileCopy.connect(this, &FileOperation::operationCancel, &fileCopy, &FileCopy::cancel, Qt::DirectConnection);
+        if (m_is_pause) fileCopy.pause();
+        fileCopy.run();
 
         if (err) {
             setHasError(true);
@@ -757,25 +843,37 @@ fallback_retry:
                 break;
             }
             case OverWriteOne: {
-                g_file_copy(sourceFile.get()->get(),
-                            destFile.get()->get(),
-                            GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_OVERWRITE),
-                            getCancellable().get()->get(),
-                            GFileProgressCallback(progress_callback),
-                            this,
-                            nullptr);
-                //node->setState(FileNode::Handled);
+                FileCopy fileCopy (node->uri(), realDestUri, GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_OVERWRITE),
+                                   getCancellable().get()->get(),
+                                   GFileProgressCallback(progress_callback),
+                                   this,
+                                   &err);
+                fileCopy.connect(this, &FileOperation::operationPause, &fileCopy, &FileCopy::pause, Qt::DirectConnection);
+                fileCopy.connect(this, &FileOperation::operationResume, &fileCopy, &FileCopy::resume, Qt::DirectConnection);
+                fileCopy.connect(this, &FileOperation::operationCancel, &fileCopy, &FileCopy::cancel, Qt::DirectConnection);
+                if (m_is_pause) fileCopy.pause();
+                fileCopy.run();
                 node->setErrorResponse(OverWriteOne);
                 break;
             }
             case OverWriteAll: {
-                g_file_copy(sourceFile.get()->get(),
-                            destFile.get()->get(),
-                            GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_OVERWRITE),
-                            getCancellable().get()->get(),
-                            GFileProgressCallback(progress_callback),
-                            this,
-                            nullptr);
+//                g_file_copy(sourceFile.get()->get(),
+//                            destFile.get()->get(),
+//                            GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_OVERWRITE),
+//                            getCancellable().get()->get(),
+//                            GFileProgressCallback(progress_callback),
+//                            this,
+//                            nullptr);
+                FileCopy fileCopy (node->uri(), realDestUri, GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_OVERWRITE),
+                                   getCancellable().get()->get(),
+                                   GFileProgressCallback(progress_callback),
+                                   this,
+                                   &err);
+                fileCopy.connect(this, &FileOperation::operationPause, &fileCopy, &FileCopy::pause, Qt::DirectConnection);
+                fileCopy.connect(this, &FileOperation::operationResume, &fileCopy, &FileCopy::resume, Qt::DirectConnection);
+                fileCopy.connect(this, &FileOperation::operationCancel, &fileCopy, &FileCopy::cancel, Qt::DirectConnection);
+                if (m_is_pause) fileCopy.pause();
+                fileCopy.run();
                 //node->setState(FileNode::Handled);
                 node->setErrorResponse(OverWriteOne);
                 m_prehandle_hash.insert(err->code, OverWriteOne);
@@ -803,13 +901,16 @@ fallback_retry:
                 }
                 auto handledDestFileUri = node->resolveDestFileUri(m_dest_dir_uri);
                 auto handledDestFile = wrapGFile(g_file_new_for_uri(handledDestFileUri.toUtf8()));
-                g_file_copy(sourceFile.get()->get(),
-                            handledDestFile.get()->get(),
-                            GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_BACKUP),
-                            getCancellable().get()->get(),
-                            GFileProgressCallback(progress_callback),
-                            this,
-                            nullptr);
+                FileCopy fileCopy (node->uri(), realDestUri, GFileCopyFlags(m_default_copy_flag | G_FILE_COPY_BACKUP),
+                                   getCancellable().get()->get(),
+                                   GFileProgressCallback(progress_callback),
+                                   this,
+                                   &err);
+                fileCopy.connect(this, &FileOperation::operationPause, &fileCopy, &FileCopy::pause, Qt::DirectConnection);
+                fileCopy.connect(this, &FileOperation::operationResume, &fileCopy, &FileCopy::resume, Qt::DirectConnection);
+                fileCopy.connect(this, &FileOperation::operationCancel, &fileCopy, &FileCopy::cancel, Qt::DirectConnection);
+                if (m_is_pause) fileCopy.pause();
+                fileCopy.run();
                 //node->setState(FileNode::Handled);
                 node->setErrorResponse(BackupOne);
                 setHasError(false);
@@ -831,12 +932,10 @@ fallback_retry:
             default:
                 break;
             }
-        } else {
-            //node->setState(FileNode::Handled);
         }
         fileSync(node->uri(), realDestUri);
         m_current_offset += node->size();
-        auto fileIconName = FileUtils::getFileIconName(m_current_src_uri, false);
+        auto fileIconName = FileUtilsPrivate::getFileIconName(m_current_src_uri);
         auto destFileName = FileUtils::isFileDirectory(node->destUri()) ? nullptr : node->destUri();
         Q_EMIT FileProgressCallback(node->uri(), destFileName, fileIconName, m_current_offset, m_total_szie);
         Q_EMIT operationProgressedOne(node->uri(), node->destUri(), node->size());
@@ -850,7 +949,7 @@ void FileMoveOperation::deleteRecursively(FileNode *node)
     if (isCancelled())
         return;
 
-    GFile *file = g_file_new_for_uri(node->uri().toUtf8().constData());
+    g_autoptr(GFile) file = g_file_new_for_uri(node->uri().toUtf8().constData());
     if (node->isFolder()) {
         for (auto child : *(node->children())) {
             deleteRecursively(child);
@@ -865,7 +964,6 @@ void FileMoveOperation::deleteRecursively(FileNode *node)
             node->setState(FileNode::Handled);
         }
     }
-    g_object_unref(file);
     operationAfterProgressedOne(node->uri());
 }
 
@@ -898,10 +996,14 @@ void FileMoveOperation::moveForceUseFallback()
     }
     operationProgressed();
 
-    if (!m_copy_move) {
+    if (m_move_action == Qt::TargetMoveAction) {
+        m_info.get()->m_type = FileOperationInfo::Move;
         for (auto node : nodes) {
             deleteRecursively(node);
         }
+    } else {
+        m_info.get()->m_type = FileOperationInfo::Copy;
+        m_info.get()->m_opposite_type = FileOperationInfo::Delete;
     }
 
     if (isCancelled())
@@ -925,6 +1027,30 @@ void FileMoveOperation::moveForceUseFallback()
     nodes.clear();
 }
 
+void FileMoveOperation::moveForceUseFallback(FileNode* node)
+{
+    if (isCancelled() || nullptr == node)
+        return;
+
+    operationPrepared();
+
+    copyRecursively(node);
+
+    if (isCancelled()) {
+        Q_EMIT operationStartRollbacked();
+    }
+
+    if (m_move_action == Qt::TargetMoveAction) {
+        deleteRecursively(node);
+    }
+
+    node->setState(FileNode::Handled);
+
+    if (isCancelled()) {
+        rollbackNodeRecursively(node);
+    }
+}
+
 bool FileMoveOperation::isValid()
 {
     int index = 0;
@@ -948,6 +1074,10 @@ bool FileMoveOperation::isValid()
         //it will call G_IO_ERROR_INVALID_FILENAME
         ++index;
     }
+    //can not move StandardPath to any dir. see:#87912
+    if (FileUtils::containsStandardPath(m_source_uris)) {
+        isInvalid = true;
+    }
     if (isInvalid)
         invalidExited(tr("Invalid Operation."));
     return !isInvalid;
@@ -985,33 +1115,15 @@ start:
         return;
 
     //should block and wait for other object prepared.
-    if (!m_force_use_fallback) {
-        move();
-    }
+    move();
+//    if (!m_force_use_fallback) {
+//        move();
+//    }
 
-    //ensure again
-    if (m_force_use_fallback) {
-        moveForceUseFallback();
-        operationStartSnyc();
 
-        auto info = getOperationInfo();
-        auto destDirUri = info.get()->m_dest_dir_uri;
-        auto dest_file = g_file_new_for_uri(destDirUri.toUtf8().constData());
-        auto path = g_file_get_path(dest_file);
-        g_object_unref(dest_file);
-//        if (path) {
-//            QProcess p;
-//            auto shell_path = g_shell_quote(path);
-//            g_free(path);
-//            p.start(QString("sync -d %1").arg(shell_path));
-//            g_free(shell_path);
-//            p.waitForFinished(-1);
-//        }
-    }
     qDebug()<<"finished";
 end:
     Q_EMIT operationFinished();
-    //notifyFileWatcherOperationFinished();
 }
 
 void FileMoveOperation::cancel()
