@@ -137,7 +137,8 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
     m_go_back = goBack;
     goBack->setEnabled(false);
     goBack->setToolTip(tr("Go Back"));
-    goBack->setFixedSize(QSize(36, 28));
+    goBack->setFixedSize(QSize(40, 40));
+    goBack->setIconSize(QSize(16, 16));
     goBack->setIcon(QIcon::fromTheme("go-previous-symbolic"));
     addWidget(goBack);
 
@@ -145,14 +146,15 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
     m_go_forward = goForward;
     goForward->setEnabled(false);
     goForward->setToolTip(tr("Go Forward"));
-    goForward->setFixedSize(QSize(36, 28));
+    goForward->setFixedSize(QSize(40, 40));
+    goForward->setIconSize(QSize(16, 16));
     goForward->setIcon(QIcon::fromTheme("go-next-symbolic"));
     addWidget(goForward);
     connect(goForward, &QPushButton::clicked, m_window, [=]() {
         m_window->getCurrentPage()->goForward();
     });
 
-    addSpacing(9);
+    addSpacing(ADDRESS_BAR_LEFT_WIDTH);
 
     auto locationBar = new Peony::AdvancedLocationBar(this);
     locationBar->setMinimumWidth(ADDRESS_BAR_MINIMUN_WIDTH);
@@ -162,7 +164,7 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
 
     connect(goBack, &QPushButton::clicked, m_window, [=]() {
         m_window->getCurrentPage()->goBack();
-        m_location_bar->clearSearchBox();
+        quitSerachMode();
     });
 
     connect(m_location_bar, &Peony::AdvancedLocationBar::refreshRequest, [=]()
@@ -190,7 +192,7 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
 
     connect(m_location_bar, &Peony::AdvancedLocationBar::updateWindowLocationRequest, this, &HeaderBar::updateLocationRequest);
 
-    addSpacing(9 - 7);
+    addSpacing(ADDRESS_BAR_RIGHT_WIDTH);
 //    auto a = addAction(QIcon::fromTheme("edit-find-symbolic"), tr("Search"));
 //    connect(a, &QAction::triggered, this, &HeaderBar::searchButtonClicked);
 //    auto search = qobject_cast<QToolButton *>(widgetForAction(a));
@@ -202,79 +204,13 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
     //use theme buttons
     auto search = new HeadBarPushButton(this);
     m_search_button = search;
-    search->setFixedSize(QSize(40, 40));
+    search->setFixedSize(QSize(SEARCH_BTN_WIDTH, SEARCH_BTN_WIDTH));
     search->setIconSize(QSize(16, 16));
     search->setIcon(QIcon::fromTheme("edit-find-symbolic"));
     search->setToolTip(tr("Search"));
     addWidget(search);
     connect(search, &QPushButton::clicked, this, &HeaderBar::searchButtonClicked);
 
-    addSpacing(DRAG_AREA_DEFAULT_WIDTH);
-
-    auto a = addAction(QIcon::fromTheme("view-grid-symbolic"), tr("View Type"));
-    auto viewType = qobject_cast<QToolButton *>(widgetForAction(a));
-    viewType->setAutoRaise(false);
-    viewType->setFixedSize(QSize(57, 40));
-    viewType->setIconSize(QSize(16, 16));
-    viewType->setPopupMode(QToolButton::InstantPopup);
-
-    m_view_type_menu = new ViewTypeMenu(viewType);
-    a->setMenu(m_view_type_menu);
-
-    connect(m_view_type_menu, &ViewTypeMenu::switchViewRequest, this, [=](const QString &id, const QIcon &icon, bool resetToZoomLevel) {
-        viewType->setText(id);
-        viewType->setIcon(icon);
-        this->viewTypeChangeRequest(id);
-        if (resetToZoomLevel) {
-            auto viewId = m_window->getCurrentPage()->getView()->viewId();
-            auto factoryManger = Peony::DirectoryViewFactoryManager2::getInstance();
-            auto factory = factoryManger->getFactory(viewId);
-            int zoomLevelHint = factory->zoom_level_hint();
-            m_window->getCurrentPage()->setZoomLevelRequest(zoomLevelHint);
-        }
-    });
-
-    connect(m_view_type_menu, &ViewTypeMenu::updateZoomLevelHintRequest, this, &HeaderBar::updateZoomLevelHintRequest);
-
-    addSpacing(2);
-
-    a = addAction(QIcon::fromTheme("view-sort-ascending-symbolic"), tr("Sort Type"));
-    auto sortType = qobject_cast<QToolButton *>(widgetForAction(a));
-    sortType->setAutoRaise(false);
-    sortType->setFixedSize(QSize(57, 40));
-    sortType->setIconSize(QSize(16, 16));
-    sortType->setPopupMode(QToolButton::InstantPopup);
-
-    m_sort_type_menu = new SortTypeMenu(this);
-    a->setMenu(m_sort_type_menu);
-
-    connect(m_sort_type_menu, &SortTypeMenu::switchSortTypeRequest, m_window, &MainWindow::setCurrentSortColumn);
-    connect(m_sort_type_menu, &SortTypeMenu::switchSortOrderRequest, m_window, [=](Qt::SortOrder order) {
-        if (order == Qt::AscendingOrder) {
-            sortType->setIcon(QIcon::fromTheme("view-sort-ascending-symbolic"));
-        } else {
-            sortType->setIcon(QIcon::fromTheme("view-sort-descending-symbolic"));
-        }
-        m_window->setCurrentSortOrder(order);
-    });
-    connect(m_sort_type_menu, &QMenu::aboutToShow, m_sort_type_menu, [=]() {
-        m_sort_type_menu->setSortType(m_window->getCurrentSortColumn());
-        m_sort_type_menu->setSortOrder(m_window->getCurrentSortOrder());
-    });
-
-    addSpacing(2);
-
-    a = addAction(QIcon::fromTheme("open-menu-symbolic"), tr("Option"));
-    auto popMenu = qobject_cast<QToolButton *>(widgetForAction(a));
-    popMenu->setProperty("isOptionButton", true);
-    popMenu->setAutoRaise(false);
-    popMenu->setFixedSize(QSize(40, 40));
-    popMenu->setIconSize(QSize(16, 16));
-    popMenu->setPopupMode(QToolButton::InstantPopup);
-
-    m_operation_menu = new OperationMenu(m_window, this);
-    a->setMenu(m_operation_menu);
-
 //    createFolder->setFlat(true);
 //    createFolder->setProperty("isWindowButton", 1);
 //    createFolder->setProperty("useIconHighlightEffect", 2);
@@ -286,9 +222,9 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
 //    openTerminal->setProperty("isIcon", true);
 
     search->setFlat(true);
-    search->setProperty("isWindowButton", 1);
-    search->setProperty("useIconHighlightEffect", 2);
-    search->setProperty("isIcon", true);
+    //fix:bug#93521,修改控件三态
+    search->setProperty("useIconHighlightEffect", true);
+    search->setProperty("iconHighlightEffectMode", 1);
 
     goBack->setFlat(true);
     goBack->setProperty("isWindowButton", 1);
@@ -299,26 +235,16 @@ HeaderBar::HeaderBar(MainWindow *parent) : QToolBar(parent)
     goForward->setProperty("useIconHighlightEffect", 2);
     goForward->setProperty("isIcon", true);
 
-    for (auto action : actions()) {
-        auto w = widgetForAction(action);
-
-        if (w != search && qobject_cast<QToolButton *>(w)) {
-            w->setProperty("isWindowButton", 1);
-            if (auto toolButton = qobject_cast<QToolButton *>(w)) {
-                toolButton->setAutoRaise(true);
-            }
-            w->setProperty("useIconHighlightEffect", 2);
-        }
-    }
-
+    addMenuButtons();
+    setMinimumWidth(GBACK_BTN_WIDTH * 2
+                    + ADDRESS_BAR_LEFT_WIDTH + ADDRESS_BAR_MINIMUN_WIDTH + ADDRESS_BAR_RIGHT_WIDTH
+                    + SEARCH_BTN_WIDTH
+                    + DRAG_AREA_MINIMUN_WIDTH);
 //    m_focus_list<<(createFolder);
 //    m_focus_list<<(openTerminal);
     m_focus_list<<(goBack);
     m_focus_list<<(goForward);
     m_focus_list<<(search);
-    m_focus_list<<(viewType);
-    m_focus_list<<(sortType);
-    m_focus_list<<(popMenu);
 }
 
 void HeaderBar::findDefaultTerminal()
@@ -424,9 +350,104 @@ void HeaderBar::updateSearchRecursive(bool recursive)
 
 void HeaderBar::addSpacing(int pixel)
 {
-    for (int i = 0; i < pixel; i++) {
-        addSeparator();
+    QWidget *widget = new QWidget(this);
+    widget->setFixedSize(QSize((pixel < 1 ? 1 : pixel), 40));
+    widget->setAttribute(Qt::WA_TranslucentBackground);
+
+    addWidget(widget);
+//    for (int i = 0; i < pixel; i++) {
+//        addSeparator();
+//    }
+}
+
+void HeaderBar::addMenuButtons()
+{
+    //占位widget,5个widget共同组成拖动区域,共宽150px
+    for (int i = 1; i <= 5; ++i) {
+        QWidget *widget = new QWidget(this);
+        widget->setFixedSize(QSize(i * 10, 40));
+        widget->setAttribute(Qt::WA_TranslucentBackground);
+        addWidget(widget);
     }
+
+    QAction *action = addAction(QIcon::fromTheme("view-grid-symbolic"), tr("View Type"));
+    QToolButton *viewType = qobject_cast<QToolButton *>(widgetForAction(action));
+    viewType->setAutoRaise(true);
+    viewType->setFixedSize(QSize(57, 40));
+    viewType->setIconSize(QSize(16, 16));
+    viewType->setPopupMode(QToolButton::InstantPopup);
+
+    ViewTypeMenu* viewTypeMenu = new ViewTypeMenu(viewType);
+    m_view_type_menu = viewTypeMenu;
+    action->setMenu(viewTypeMenu);
+
+    connect(viewTypeMenu, &ViewTypeMenu::switchViewRequest, this, [=](const QString &id, const QIcon &icon, bool resetToZoomLevel) {
+        viewType->setText(id);
+        viewType->setIcon(icon);
+        viewTypeChangeRequest(id);
+        if (resetToZoomLevel) {
+            auto viewId = m_window->getCurrentPage()->getView()->viewId();
+            auto factoryManger = Peony::DirectoryViewFactoryManager2::getInstance();
+            auto factory = factoryManger->getFactory(viewId);
+            int zoomLevelHint = factory->zoom_level_hint();
+            m_window->getCurrentPage()->setZoomLevelRequest(zoomLevelHint);
+        }
+    });
+
+    connect(viewTypeMenu, &ViewTypeMenu::updateZoomLevelHintRequest, this, &HeaderBar::updateZoomLevelHintRequest);
+
+    action = addAction(QIcon::fromTheme("view-sort-ascending-symbolic"), tr("Sort Type"));
+    QToolButton *sortType = qobject_cast<QToolButton *>(widgetForAction(action));
+    sortType->setAutoRaise(true);
+    sortType->setFixedSize(QSize(57, 40));
+    sortType->setIconSize(QSize(16, 16));
+    sortType->setPopupMode(QToolButton::InstantPopup);
+
+    SortTypeMenu *sortTypeMenu = new SortTypeMenu(sortType);
+    m_sort_type_menu = sortTypeMenu;
+    action->setMenu(sortTypeMenu);
+
+    connect(sortTypeMenu, &SortTypeMenu::switchSortTypeRequest, m_window, &MainWindow::setCurrentSortColumn);
+    connect(sortTypeMenu, &SortTypeMenu::switchSortOrderRequest, m_window, [=](Qt::SortOrder order) {
+        if (order == Qt::AscendingOrder) {
+            sortType->setIcon(QIcon::fromTheme("view-sort-ascending-symbolic"));
+        } else {
+            sortType->setIcon(QIcon::fromTheme("view-sort-descending-symbolic"));
+        }
+        m_window->setCurrentSortOrder(order);
+    });
+    connect(sortTypeMenu, &QMenu::aboutToShow, sortTypeMenu, [=]() {
+        sortTypeMenu->setSortType(m_window->getCurrentSortColumn());
+        sortTypeMenu->setSortOrder(m_window->getCurrentSortOrder());
+    });
+
+    action = addAction(QIcon::fromTheme("open-menu-symbolic"), tr("Option"));
+    QToolButton *popMenu = qobject_cast<QToolButton *>(widgetForAction(action));
+    popMenu->setAutoRaise(false);
+    popMenu->setFixedSize(QSize(40, 40));
+    popMenu->setIconSize(QSize(16, 16));
+    popMenu->setProperty("isOptionButton", true);
+    popMenu->setPopupMode(QToolButton::InstantPopup);
+
+    OperationMenu *operationMenu = new OperationMenu(m_window, popMenu);
+    m_operation_menu = operationMenu;
+    action->setMenu(operationMenu);
+
+    viewType->setProperty("isWindowButton", 1);
+    viewType->setProperty("useIconHighlightEffect", 0x2);
+    viewType->setAutoRaise(true);
+
+    sortType->setProperty("isWindowButton", 1);
+    sortType->setProperty("useIconHighlightEffect", 0x2);
+    sortType->setAutoRaise(true);
+
+    popMenu->setProperty("isWindowButton", 1);
+    popMenu->setProperty("useIconHighlightEffect", 0x2);
+    popMenu->setAutoRaise(true);
+
+    m_focus_list << (viewType);
+    m_focus_list << (sortType);
+    m_focus_list << (popMenu);
 }
 
 void HeaderBar::mouseMoveEvent(QMouseEvent *e)
@@ -437,6 +458,15 @@ void HeaderBar::mouseMoveEvent(QMouseEvent *e)
     this->topLevelWidget()->setCursor(c);
 }
 
+//fix Right click in the blank space on the right side of the tab to quickly maximize and restore the window. link bug102455
+void HeaderBar::mouseDoubleClickEvent(QMouseEvent *e)
+{
+    QToolBar::mouseDoubleClickEvent(e);
+    if(e->button() == Qt::LeftButton || e->button() == Qt::RightButton){
+        m_window->maximizeOrRestore();
+    }
+}
+
 void HeaderBar::setLocation(const QString &uri)
 {
     m_location_bar->updateLocation(uri);
@@ -470,19 +500,30 @@ void HeaderBar::finishEdit()
     m_location_bar->finishEdit();
 }
 
+void HeaderBar::quitSerachMode()
+{
+    if (m_search_mode)
+       m_location_bar->clearSearchBox();
+}
+
 void HeaderBar::updateIcons()
 {
+    if(!m_window)
+        return;
     qDebug()<<"updateIcons:" <<m_window->getCurrentUri();
     qDebug()<<"updateIcons:" <<m_window->getCurrentSortColumn();
     qDebug()<<"updateIcons:" <<m_window->getCurrentSortOrder();
     m_view_type_menu->setCurrentDirectory(m_window->getCurrentUri());
-    m_view_type_menu->setCurrentView(m_window->getCurrentPage()->getView()->viewId(), true);
+    if(m_window->getCurrentPage() && m_window->getCurrentPage()->getView())
+        m_view_type_menu->setCurrentView(m_window->getCurrentPage()->getView()->viewId(), true);
     m_sort_type_menu->switchSortTypeRequest(m_window->getCurrentSortColumn());
     m_sort_type_menu->switchSortOrderRequest(m_window->getCurrentSortOrder());
 
     //go back & go forward
-    m_go_back->setEnabled(m_window->getCurrentPage()->canGoBack());
-    m_go_forward->setEnabled(m_window->getCurrentPage()->canGoForward());
+    if(m_window->getCurrentPage()){
+        m_go_back->setEnabled(m_window->getCurrentPage()->canGoBack());
+        m_go_forward->setEnabled(m_window->getCurrentPage()->canGoForward());
+    }
 
     //fix create folder fail issue in special path
 //    auto curUri = m_window->getCurrentUri();
@@ -495,7 +536,20 @@ void HeaderBar::updateIcons()
 //        m_create_folder->setEnabled(false);
 
     //maximize & restore
-    updateMaximizeState();
+    //updateMaximizeState();
+}
+
+void HeaderBar::updateViewTypeEnable()
+{
+    auto url = m_window->getCurrentUri();
+    //qDebug() << "updateViewTypeEnable url:" << url;
+    if(url == "computer:///"){
+        m_view_type_menu->setEnabled(false);
+        m_view_type_menu->menuAction()->setVisible(false);
+    }else{
+        m_view_type_menu->setEnabled(true);
+        m_view_type_menu->menuAction()->setVisible(true);
+    }
 }
 
 void HeaderBar::updateHeaderState()
@@ -506,10 +560,30 @@ void HeaderBar::updateHeaderState()
 //        m_create_folder->setEnabled(false);
 }
 
+void HeaderBar::updateSortTypeEnable()
+{
+    auto url = m_window->getCurrentUri();
+    qDebug() << "url:" << url;
+    if(url == "computer:///"){
+        m_sort_type_menu->setEnabled(false);
+        m_sort_type_menu->menuAction()->setVisible(false);
+    }else{
+        m_sort_type_menu->setEnabled(true);
+        m_sort_type_menu->menuAction()->setVisible(true);
+    }
+}
+
 void HeaderBar::updateMaximizeState()
 {
     //maximize & restore
-    //do it in container
+    bool maximized = m_window->isMaximized();
+    if (maximized) {
+        m_maximize_restore_button->setIcon(QIcon::fromTheme("window-restore-symbolic"));
+        m_maximize_restore_button->setToolTip(tr("Restore"));
+    } else {
+        m_maximize_restore_button->setIcon(QIcon::fromTheme("window-maximize-symbolic"));
+        m_maximize_restore_button->setToolTip(tr("Maximize"));
+    }
 }
 
 //HeaderBarToolButton
@@ -608,23 +682,17 @@ bool HeaderBarContainer::eventFilter(QObject *obj, QEvent *e)
     Q_UNUSED(obj)
     auto window = qobject_cast<MainWindow *>(obj);
     if (window) {
-        if (e->type() == QEvent::Resize) {
-            if (window->isMaximized()) {
-                m_max_or_restore->setIcon(QIcon::fromTheme("window-restore-symbolic"));
-                //m_max_or_restore->setToolTip(tr("Restore"));
-            } else {
-                m_max_or_restore->setIcon(QIcon::fromTheme("window-maximize-symbolic"));
-                //m_max_or_restore->setToolTip(tr("Maximize"));
-            }
+        //use updateMaximizeState function, comment those code
+        if (e->type() == QEvent::Resize || QEvent::WindowStateChange == e->type()) {
+            //fix bug#95419, drag change window to restore not change state issue
+            m_header_bar->updateMaximizeState();
         }
         //fix double click space window has no change issue, bug#38499
-        else if (e->type() == QEvent::MouseButtonDblClick)
-        {
-            if (window->isMaximized())
-                window->showNormal();
-            else
-                window->showMaximized();
-        }
+        //fix Right click in the blank space on the right side of the tab to quickly maximize and restore the window. link bug102455
+//        if (e->type() == QEvent::MouseButtonDblClick)
+//        {
+//            m_header_bar->m_window->maximizeOrRestore();
+//        }
         return false;
     } else {
         if (e->type() == QEvent::MouseMove) {
@@ -683,22 +751,14 @@ void HeaderBarContainer::addWindowButtons()
     //window-maximize-symbolic
     //window-restore-symbolic
     auto maximizeAndRestore = new QToolButton(m_internal_widget);
-    maximizeAndRestore->setToolTip(tr("Maximize/Restore"));
-    maximizeAndRestore->setIcon(QIcon::fromTheme("window-maximize-symbolic"));
+    m_header_bar->m_maximize_restore_button = maximizeAndRestore;
+    //switch tips with button status, fix bug#77604
+    m_header_bar->updateMaximizeState();
     maximizeAndRestore->setAutoRaise(false);
     maximizeAndRestore->setFixedSize(QSize(40, 40));
     maximizeAndRestore->setIconSize(QSize(16, 16));
     connect(maximizeAndRestore, &QToolButton::clicked, this, [=]() {
         m_header_bar->m_window->maximizeOrRestore();
-
-        bool maximized = m_header_bar->m_window->isMaximized();
-        if (maximized) {
-            maximizeAndRestore->setIcon(QIcon::fromTheme("window-restore-symbolic"));
-            //maximizeAndRestore->setToolTip(tr("Restore"));
-        } else {
-            maximizeAndRestore->setIcon(QIcon::fromTheme("window-maximize-symbolic"));
-            //maximizeAndRestore->setToolTip(tr("Maximize"));
-        }
     });
     m_max_or_restore = maximizeAndRestore;
 
@@ -718,23 +778,24 @@ void HeaderBarContainer::addWindowButtons()
     maximizeAndRestore->setAutoRaise(true);
 
     close->setProperty("isWindowButton", 2);
-    close->setProperty("useIconHighlightEffect", 0x2);
+    close->setProperty("useIconHighlightEffect", 0x8);
     close->setAutoRaise(true);
 
     connect(close, &QToolButton::clicked, this, [=]() {
         m_header_bar->m_window->close();
     });
 
-    connect(qApp, &QApplication::paletteChanged, close, [=](){
-        QTimer::singleShot(100, this, [=](){
-            auto palette = qApp->palette();
-            palette.setColor(QPalette::Highlight, QColor("#E54A50"));
-            close->setPalette(palette);
-        });
-    });
-    auto palette = qApp->palette();
-    palette.setColor(QPalette::Highlight, QColor("#E54A50"));
-    close->setPalette(palette);
+    //fix bug#98500, comment self change palette code, use platform-theme way
+//    connect(qApp, &QApplication::paletteChanged, close, [=](){
+//        QTimer::singleShot(100, this, [=](){
+//            auto palette = qApp->palette();
+//            palette.setColor(QPalette::Highlight, QColor("#E54A50"));
+//            close->setPalette(palette);
+//        });
+//    });
+//    auto palette = qApp->palette();
+//    palette.setColor(QPalette::Highlight, QColor("#E54A50"));
+//    close->setPalette(palette);
 
     layout->addWidget(minimize);
     layout->addWidget(maximizeAndRestore);
