@@ -28,6 +28,8 @@
 #include "directory-view-widget.h"
 
 #include "file-info.h"
+#include "file-utils.h"
+#include "file-info-job.h"
 #include "file-launch-manager.h"
 #include "search-vfs-uri-parser.h"
 #include "properties-window.h"
@@ -56,6 +58,7 @@
 #include "volume-manager.h"
 
 #include "file-info-job.h"
+#include "global-settings.h"
 
 #include <QApplication>
 #include <QStandardPaths>
@@ -64,6 +67,85 @@
 
 #include <QDebug>
 
+static PushButtonStyle *global_instance = nullptr;
+
+PushButtonStyle *PushButtonStyle::getStyle()
+{
+    if (!global_instance) {
+        global_instance = new PushButtonStyle;
+    }
+    return global_instance;
+}
+
+void PushButtonStyle::drawControl(QStyle::ControlElement element, const QStyleOption *option, QPainter *painter, const QWidget *widget) const
+{
+    switch (element) {
+    case CE_PushButton:
+    {
+        if (const QStyleOptionButton *button = qstyleoption_cast<const QStyleOptionButton *>(option)) {
+            proxy()->drawControl(CE_PushButtonBevel, option, painter, widget);
+            QStyleOptionButton subopt = *button;
+            subopt.rect = proxy()->subElementRect(SE_PushButtonContents, option, widget);
+            proxy()->drawControl(CE_PushButtonLabel, &subopt, painter, widget);
+            return;
+        }
+        break;
+    }
+
+    default:
+        break;
+    }
+    QProxyStyle::drawControl(element, option, painter, widget);
+}
+
+int PushButtonStyle::pixelMetric(QStyle::PixelMetric metric, const QStyleOption *option, const QWidget *widget) const
+{
+    switch (metric) {
+    case PM_ButtonMargin:
+    {
+        return 0;
+    }
+
+    default:
+        return QProxyStyle::pixelMetric(metric, option, widget);
+    }
+}
+
+QRect PushButtonStyle::subElementRect(SubElement element, const QStyleOption *option, const QWidget *widget) const
+{
+    switch (element) {
+    case SE_PushButtonContents:
+    {
+        if (const QStyleOptionButton *button = qstyleoption_cast<const QStyleOptionButton *>(option)) {
+            const bool icon = !button->icon.isNull();
+            const bool text = !button->text.isEmpty();
+            QRect rect = option->rect;
+            int Margin_Height = 2;
+            int ToolButton_MarginWidth = 10;
+            int Button_MarginWidth = proxy()->pixelMetric(PM_ButtonMargin, option, widget);
+            if (text && !icon && !(button->features & QStyleOptionButton::HasMenu)) {
+                rect.adjust(Button_MarginWidth, 0, -Button_MarginWidth, 0);
+            } else if (!text && icon && !(button->features & QStyleOptionButton::HasMenu)) {
+
+            } else {
+                rect.adjust(ToolButton_MarginWidth, Margin_Height, -ToolButton_MarginWidth, -Margin_Height);
+            }
+            if (button->features & (QStyleOptionButton::AutoDefaultButton | QStyleOptionButton::DefaultButton)) {
+                int dbw = proxy()->pixelMetric(PM_ButtonDefaultIndicator, option, widget);
+                rect.adjust(dbw, dbw, -dbw, -dbw);
+            }
+            return rect;
+        }
+        break;
+    }
+
+    default:
+        break;
+    }
+
+    return QProxyStyle::subElementRect(element, option, widget);
+}
+
 TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
 {
     setStyle(PeonyMainWindowStyle::getStyle());
@@ -76,10 +158,12 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
     m_stack->setContentsMargins(0, 0, 0, 0);
     m_buttons = new PreviewPageButtonGroups(this);
     m_preview_page_container = new QStackedWidget(this);
-    m_preview_page_container->setMinimumWidth(200);
+    m_preview_page_container->setContentsMargins(0, 2, 0, 0);
+    m_preview_page_container->setMinimumWidth(300);
 
     //status bar
     m_status_bar = new TabStatusBar(this, this);
+    connect(this, &TabWidget::updateItemsNum, m_status_bar, &TabStatusBar::updateItemsNum);
     connect(this, &TabWidget::zoomRequest, m_status_bar, &TabStatusBar::onZoomRequest);
     connect(m_status_bar, &TabStatusBar::zoomLevelChangedRequest, this, &TabWidget::handleZoomLevel);
     //setStatusBar(m_status_bar);
@@ -97,8 +181,14 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
     connect(m_tab_bar, &QTabBar::currentChanged, this, &TabWidget::changeCurrentIndex);
     connect(m_tab_bar, &QTabBar::tabMoved, this, &TabWidget::moveTab);
     connect(m_tab_bar, &QTabBar::tabCloseRequested, this, &TabWidget::removeTab);
+    connect(m_tab_bar, &NavigationTabBar::pageRemoved, this, [this]{
+        updateTabBarGeometry();
+    });
     connect(m_tab_bar, &NavigationTabBar::addPageRequest, this, &TabWidget::addPage);
     connect(m_tab_bar, &NavigationTabBar::locationUpdated, this, &TabWidget::updateSearchPathButton);
+    connect(m_tab_bar, &NavigationTabBar::locationUpdated, this, [this]{
+        updateTabBarGeometry();
+    });
 
     connect(m_tab_bar, &NavigationTabBar::closeWindowRequest, this, &TabWidget::closeWindowRequest);
 
@@ -108,8 +198,14 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
     m_tab_bar_bg = new QWidget(this);
     m_tab_bar_bg->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     QToolBar *previewButtons = new QToolBar(this);
+    previewButtons->setMovable(false);
+    previewButtons->setAttribute(Qt::WA_TranslucentBackground);
+    previewButtons->setAutoFillBackground(false);
+    previewButtons->setObjectName("previewButtons");
+    previewButtons->setStyle(TabBarStyle::getStyle());
     m_tool_bar = previewButtons;
-    //previewButtons->setFixedHeight(m_tab_bar->height());
+   // previewButtons->setFixedSize(QSize(40, 40));
+    previewButtons->setIconSize(QSize(16,16));
     t->setContentsMargins(0, 0, 5, 0);
     t->addWidget(m_tab_bar_bg);
 
@@ -118,21 +214,17 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
     spacer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     t->addWidget(spacer);
     auto addPageButton = new QToolButton(this);
+    m_add_page_button = addPageButton;
+    addPageButton->setObjectName("addPageButton");
+    addPageButton->setProperty("isWindowButton", 1);
+    addPageButton->setStyle(TabBarStyle::getStyle());
     addPageButton->setIcon(QIcon::fromTheme("list-add-symbolic"));
     spacer->setVisible(false);
-    addPageButton->setVisible(false);
     addPageButton->setFixedSize(m_tab_bar->height() + 2, m_tab_bar->height() + 2);
-    addPageButton->setProperty("useIconHighlightEffect", true);
-    addPageButton->setProperty("iconHighlightEffectMode", 1);
-    addPageButton->setProperty("fillIconSymbolicColor", true);
+    addPageButton->setProperty("useIconHighlightEffect", 2);
+//    addPageButton->setProperty("iconHighlightEffectMode", 1);
+//    addPageButton->setProperty("fillIconSymbolicColor", true);
 
-    connect(m_tab_bar, &NavigationTabBar::floatButtonVisibleChanged, addPageButton, [=](bool visible, int yoffset){
-        spacer->setVisible(!visible);
-        addPageButton->setVisible(!visible);
-        addPageButton->raise();
-        if (!visible)
-            addPageButton->move(m_tab_bar->width() + qApp->style()->pixelMetric(QStyle::PM_ToolBarItemSpacing), yoffset + 4);
-    });
 
     connect(addPageButton, &QPushButton::clicked, this, [=](){
         m_tab_bar->addPageRequest(m_tab_bar->tabData(m_tab_bar->currentIndex()).toString(), true);
@@ -146,6 +238,7 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
         auto factory = manager->getPlugin(name);
         auto action = group->addAction(factory->icon(), factory->name());
         action->setCheckable(true);
+        m_preview_action = action;
         connect(action, &QAction::triggered, [=](/*bool checked*/) {
             if (!m_current_preview_action) {
                 m_current_preview_action = action;
@@ -166,23 +259,23 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
     }
     previewButtons->addActions(group->actions());
     for (auto action : group->actions()) {
-//        auto button = qobject_cast<QToolButton *>(previewButtons->widgetForAction(action));
-//        button->setFixedSize(26, 26);
-//        button->setIconSize(QSize(16, 16));
-//        button->setProperty("useIconHighlightEffect", true);
-//        button->setProperty("iconHighlightEffectMode", 1);
-//        button->setProperty("fillIconSymbolicColor", true);
+        auto button = qobject_cast<QToolButton *>(previewButtons->widgetForAction(action));
+        button->setFixedSize(26, 26);
+        button->setIconSize(QSize(16, 16));
+        button->setProperty("useIconHighlightEffect", 0x2);
+        button->setProperty("isWindowButton", 1);
+        button->setProperty("fillIconSymbolicColor", true);
 
         //use theme buttons
-        auto button = new QPushButton(this);
-        button->setFixedSize(QSize(26, 26));
-        button->setIconSize(QSize(16, 16));
-        button->setFlat(true);
-        button->setProperty("isWindowButton", 1);
-        button->setProperty("useIconHighlightEffect", 2);
-        button->setProperty("isIcon", true);
+//        auto button = new QPushButton(this);
+//        button->setFixedSize(QSize(26, 26));
+//        button->setIconSize(QSize(16, 16));
+//        button->setFlat(true);
+//        button->setProperty("isWindowButton", 1);
+//        button->setProperty("useIconHighlightEffect", 2);
+//        button->setProperty("isIcon", true);
     }
-    t->addWidget(previewButtons);
+    m_tool_bar->setFixedWidth(m_tool_bar->sizeHint().width());
 
     //trash quick operate buttons
     QHBoxLayout *trash = new QHBoxLayout();
@@ -196,7 +289,8 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
     m_trash_label = Label;
     QPushButton *clearAll = new QPushButton(tr("Clear"), trashButtons);
     clearAll->setFixedWidth(TRASH_BUTTON_WIDTH);
-    clearAll->setFixedHeight(TRASH_BUTTON_HEIGHT);
+    clearAll->setFixedHeight(TRASH_BUTTON_HEIGHT);/* Fix the bug:62841,the font of the clear button is not displayed completely */
+    clearAll->setStyle(PushButtonStyle::getStyle());
     m_clear_button = clearAll;
     QPushButton *recover = new QPushButton(tr("Recover"), trashButtons);
     recover->setFixedWidth(TRASH_BUTTON_WIDTH);
@@ -279,6 +373,11 @@ TabWidget::TabWidget(QWidget *parent) : QMainWindow(parent)
     previewButtons->setEnabled(false);
 }
 
+void TabWidget::updatePreviewButtonStatus(bool status)
+{
+   Q_EMIT m_preview_action->triggered(status);
+}
+
 void TabWidget::initAdvanceSearch()
 {
     //advance search bar
@@ -290,7 +389,11 @@ void TabWidget::initAdvanceSearch()
     m_search_close = closeButton;
     closeButton->setFixedHeight(20);
     closeButton->setFixedWidth(20);
-    closeButton->setToolTip(tr("Close advance search."));
+    closeButton->setToolTip(tr("Close Filter."));
+    closeButton->setFlat(true);
+    closeButton->setProperty("isWindowButton", 1);
+    closeButton->setProperty("useIconHighlightEffect", 2);
+    closeButton->setProperty("isIcon", true);
 
     connect(closeButton, &QPushButton::clicked, [=]()
     {
@@ -298,13 +401,15 @@ void TabWidget::initAdvanceSearch()
         Q_EMIT this->closeSearch();
     });
 
-    QLabel *title = new QLabel(tr("Search"), searchButtons);
+    QLabel *title = new QLabel(tr("Filter"), searchButtons);
     m_search_title = title;
     title->setFixedWidth(TRASH_BUTTON_WIDTH);
     title->setFixedHeight(TRASH_BUTTON_HEIGHT);
 
     QPushButton *tabButton = new QPushButton(searchButtons);
     m_search_path = tabButton;
+    m_search_path->setProperty("isWindowButton", 0x1);
+    m_search_path->setProperty("useIconHighlightEffect", 0x2);
     tabButton->setFixedHeight(TRASH_BUTTON_HEIGHT);
     tabButton->setFixedWidth(TRASH_BUTTON_WIDTH * 2);
     tabButton->setToolTip(tr("Choose other path to search."));
@@ -317,6 +422,7 @@ void TabWidget::initAdvanceSearch()
     //qDebug() << QIcon(":/custom/icons/child-folder").name();
     childButton->setIcon(QIcon(":/custom/icons/child-folder"));
     childButton->setToolTip(tr("Search recursively"));
+    m_search_child->setVisible(false);
     connect(childButton, &QPushButton::clicked, this, &TabWidget::searchChildUpdate);
     //set default select recursive
     m_search_child_flag = true;
@@ -389,7 +495,29 @@ void TabWidget::searchChildUpdate()
 
 void TabWidget::browsePath()
 {
-    QString target_path = QFileDialog::getExistingDirectory(this, tr("Select path"), getCurrentUri(), QFileDialog::ShowDirsOnly);
+    // use window modal dialog, fix #56549
+    QFileDialog f(this->topLevelWidget());
+    f.setStyle(nullptr);
+    f.setWindowTitle(tr("Select Path"));
+    f.setDirectoryUrl(QUrl(getCurrentUri()));
+    f.setWindowModality(Qt::WindowModal);
+    f.setAcceptMode(QFileDialog::AcceptOpen);
+    f.setOption(QFileDialog::ShowDirsOnly);
+    f.setFileMode(QFileDialog::DirectoryOnly);
+
+    auto result = f.exec();
+    if (result != QDialog::Accepted) {
+        return;
+    }
+
+    //Gets the URI of the selected directory. link bug#92521
+    QList<QUrl> urls = f.selectedUrls();
+    if(urls.isEmpty()){
+        return;
+    }
+    QString target_path = urls.at(0).toString();
+//    QString target_path = f.directoryUrl().toString();
+//    QString target_path = QFileDialog::getExistingDirectory(this, tr("Select path"), getCurrentUri(), QFileDialog::ShowDirsOnly);
     qDebug()<<"browsePath Opened:"<<target_path;
     //add root prefix
     if (! target_path.contains("file://") && target_path != "")
@@ -398,7 +526,10 @@ void TabWidget::browsePath()
     if (target_path != "" && target_path != getCurrentUri())
     {
         updateSearchPathButton(target_path);
-        Q_EMIT this->updateSearch(target_path);
+        /* get search key */
+        MainWindow *mainWindow = dynamic_cast<MainWindow *>(this->topLevelWidget());
+        QString key=mainWindow->getLastSearchKey();
+        Q_EMIT this->updateSearch(target_path,key);
     }
 }
 
@@ -445,16 +576,58 @@ void TabWidget::addNewConditionBar()
     inputBox->setPlaceholderText(tr("Please input key words..."));
     inputBox->setText("");
 
-    QPushButton *addButton = new QPushButton(QIcon::fromTheme("add"), "", optionBar);
+    //bug#93521 添加清除按钮
+    QToolButton* clearButton = new QToolButton(inputBox);
+    clearButton->setAttribute(Qt::WA_TranslucentBackground);
+    clearButton->setObjectName("toolButton");
+    clearButton->installEventFilter(this);
+    clearButton->setAutoRaise(true);
+    clearButton->setStyle(TabBarStyle::getStyle());
+    clearButton->setFixedSize(inputBox->height() - 4, inputBox->height() - 4);
+    QHBoxLayout* clearlayout = new QHBoxLayout(inputBox);
+    clearlayout->addStretch();
+    clearlayout->addWidget(clearButton,Qt::AlignRight);
+    clearlayout->setMargin(2);
+    inputBox->setLayout(clearlayout);
+    clearButton->setIcon(QIcon::fromTheme("edit-clear-symbolic"));
+    clearButton->setProperty("isWindowButton", 1);
+    clearButton->setProperty("useIconHighlightEffect", 0x2);
+    //clearButton->setAutoRaise(true);
+    clearButton->hide();
+
+
+    connect(clearButton, &QPushButton::clicked, this, [=](){
+        inputBox->clear();
+    });
+    connect(inputBox, &QLineEdit::textChanged, this,  [=](const QString &text){
+        if(text.isEmpty())
+        {
+            clearButton->hide();
+        }
+        else
+        {
+            clearButton->show();
+        }
+    });
+
+    QPushButton *addButton = new QPushButton(QIcon::fromTheme("list-add-symbolic"), "", optionBar);
     m_add_button_list.append(addButton);
     addButton->setFixedHeight(20);
     addButton->setFixedWidth(20);
+    addButton->setFlat(true);
+    addButton->setProperty("isWindowButton", 1);
+    addButton->setProperty("useIconHighlightEffect", 2);
+    addButton->setProperty("isIcon", true);
     connect(addButton, &QPushButton::clicked, this, &TabWidget::addNewConditionBar);
 
-    QPushButton *removeButton = new QPushButton(QIcon::fromTheme("remove"), "", optionBar);
+    QPushButton *removeButton = new QPushButton(QIcon::fromTheme("list-remove-symbolic"), "", optionBar);
     m_remove_button_list.append(removeButton);
     removeButton->setFixedHeight(20);
     removeButton->setFixedWidth(20);
+    removeButton->setFlat(true);
+    removeButton->setProperty("isWindowButton", 1);
+    removeButton->setProperty("useIconHighlightEffect", 2);
+    removeButton->setProperty("isIcon", true);
     //mapper for button clicked parse index
     auto signalMapper = new QSignalMapper(this);
     connect(removeButton, SIGNAL(clicked()), signalMapper, SLOT(map()));
@@ -481,9 +654,10 @@ void TabWidget::addNewConditionBar()
         classifyCombox->hide();
         linkLabel->setText(tr("contains"));
         //adjust label width to language
+        //use 1.5 rate width to fix big size font issue, link to bug#58824
         QLocale locale;
         if (locale.language() == QLocale::Chinese)
-            linkLabel->setFixedWidth(TRASH_BUTTON_HEIGHT);
+            linkLabel->setFixedWidth(1.5 * TRASH_BUTTON_HEIGHT);
         else
             linkLabel->setFixedWidth(TRASH_BUTTON_WIDTH);
     }
@@ -498,19 +672,23 @@ void TabWidget::addNewConditionBar()
         auto cur = conditionCombox->currentIndex();
         if (cur%4 >= 3)
         {
+            classifyCombox->setCurrentIndex(0);
             classifyCombox->hide();
             inputBox->show();
             linkLabel->setText(tr("contains"));
             //adjust label width to language
+            //use 1.5 rate width to fix big size font issue, link to bug#58824
             QLocale locale;
             if (locale.language() == QLocale::Chinese)
-                linkLabel->setFixedWidth(TRASH_BUTTON_HEIGHT);
+                linkLabel->setFixedWidth(1.5 * TRASH_BUTTON_HEIGHT);
             else
                 linkLabel->setFixedWidth(TRASH_BUTTON_WIDTH);
         }
         else
         {
             classifyCombox->show();
+            //clear old filter conditions, fix bug#83559
+            inputBox->setText("");
             inputBox->hide();
             linkLabel->setFixedWidth(TRASH_BUTTON_HEIGHT);
             linkLabel->setText(tr("is"));
@@ -594,6 +772,36 @@ QStringList TabWidget::getCurrentClassify(int rowCount)
     return currentList;
 }
 
+void TabWidget::updatePreviewPageVisible()
+{
+    auto currentUri = getCurrentUri();
+    if(currentUri.startsWith("computer://")){
+        m_preview_action->setVisible(false);
+    }else{
+        m_preview_action->setVisible(true);
+    }
+
+    auto manager = Peony::PreviewPageFactoryManager::getInstance();
+    auto pluginNames = manager->getPluginNames();
+    for (auto name : pluginNames) {
+        auto factory = manager->getPlugin(name);
+        if(m_preview_action->isChecked() && m_preview_action->isVisible()){
+            Q_EMIT m_buttons->previewPageButtonTrigger(true, factory->name());
+        }else{
+            Q_EMIT m_buttons->previewPageButtonTrigger(false, factory->name());
+        }
+    }
+}
+
+void TabWidget::updateStatusBarSliderState()
+{
+    if (currentPage() && currentPage()->getView()) {
+        bool enable = currentPage()->getView()->supportZoom();
+        m_status_bar->m_slider->setEnabled(enable);
+        m_status_bar->m_slider->setVisible(enable);
+    }
+}
+
 void TabWidget::updateTrashBarVisible(const QString &uri)
 {
     bool visible = false;
@@ -639,6 +847,68 @@ void TabWidget::handleZoomLevel(int zoomLevel)
         currentPage()->getView()->setCurrentZoomLevel(zoomLevel);
     }
 }
+#include"windows/FMWindowIface.h"
+void TabWidget::enableSearchBar(bool enable)
+{
+    //qDebug() << "enable:" <<enable;
+    m_search_path->setEnabled(enable);
+    //m_search_close->setEnabled(enable);
+    m_search_title->setEnabled(enable);
+    m_search_bar->setEnabled(enable);
+    if (m_search_bar_count >0)
+    {
+        //already had a list,just set to show
+        for(int i=0; i<m_search_bar_list.count(); i++)
+        {
+            m_conditions_list[i]->setEnabled(enable);
+            m_link_label_list[i]->setEnabled(enable);
+            if (m_conditions_list[i]->currentIndex()%4 < 3)
+                m_classify_list[i]->setEnabled(enable);
+            else
+                m_input_list[i]->setEnabled(enable);
+            m_search_bar_list[i]->setEnabled(enable);
+            m_add_button_list[i]->setEnabled(enable);
+            /* When there is only one filter item,remove button set disable */
+            if(m_search_bar_count==1)
+                m_remove_button_list[0]->setEnabled(false);
+            else
+                m_remove_button_list[i]->setEnabled(enable);
+        }
+    }
+}
+
+#include <KWindowSystem>
+void TabWidget::slot_responseUnmounted(const QString &destUri, const QString &sourceUri)
+{
+    for(int index = 0; index < m_stack->count(); index++)
+    {
+        int  currentIndex = this->currentIndex();
+        QString decodedSrcUri = Peony::FileUtils::urlDecode(sourceUri);
+        QString uri = qobject_cast<Peony::DirectoryViewContainer *>(m_stack->widget(index))->getCurrentUri();
+        uri = Peony::FileUtils::urlDecode(uri);
+        qDebug()<<"decodedSrcUri:"<<decodedSrcUri<<" uri:"<<uri<<" total count: "<<m_stack->count()<<" index:"<<index<<" currentIndex:"<<currentIndex;
+        /* 不属于该设备的tab页不处理；属于该设备：文件管理器的当前标签页跳转到计算机页，其余标签页均关闭 */
+        if(uri.contains(decodedSrcUri) && uri != "file:///" && uri!= "filesafe:///")
+        {
+            //all window accessed mount path should goto self top path，related to bug#104551
+            if((Peony::GlobalSettings::getInstance()->getValue("LAST_FOCUS_PEONY_WINID") == dynamic_cast<MainWindow *>(this->topLevelWidget())->winId()
+                ||KWindowSystem::hasWId(dynamic_cast<MainWindow *>(this->topLevelWidget())->winId()))
+                    && index == currentIndex
+                    && (decodedSrcUri == uri || Peony::FileUtils::isRemoteServerUri(decodedSrcUri))){/* 远程服务进入内部目录后卸载,link to bug#98623 */
+                qDebug()<<"sourceUri:"<<sourceUri<<"change to self top path"<<" index:"<<currentIndex;
+                if (uri.startsWith("filesafe:///"))
+                    this->goToUri("filesafe:///", true, true);  /* 跳转到文件保护箱路径 */
+                else
+                    this->goToUri(destUri, true, true);/* 跳转到计算机页 */
+            }
+            else{/* 其余tab页关闭 */
+                qDebug()<<"remove tab  uri:"<<uri<<", index:"<<index;
+                removeTab(index);
+                index--;
+            }
+        }
+    }
+}
 
 void TabWidget::updateSearchBar(bool showSearch)
 {
@@ -652,7 +922,7 @@ void TabWidget::updateSearchBar(bool showSearch)
         m_search_close->show();
         m_search_title->show();
         m_search_bar->show();
-        m_search_child->show();
+        //m_search_child->show();
         //m_search_more->show();
         m_search_bar_layout->setContentsMargins(10, 5, 10, 5);
         //m_search_more->setIcon(QIcon::fromTheme("go-down"));
@@ -664,7 +934,7 @@ void TabWidget::updateSearchBar(bool showSearch)
         m_search_close->hide();
         m_search_title->hide();
         m_search_bar->hide();
-        m_search_child->hide();
+        //m_search_child->hide();
         //m_search_more->hide();
         m_search_bar_layout->setContentsMargins(10, 0, 10, 0);
     }
@@ -678,6 +948,9 @@ void TabWidget::updateSearchBar(bool showSearch)
         clearConditions();
         updateFilter();
     }
+
+    //9X0 changes, set default as true, fix bug#70916
+    enableSearchBar(true);
 }
 
 void TabWidget::updateButtons()
@@ -718,6 +991,13 @@ void TabWidget::updateSearchPathButton(const QString &uri)
         if (! getCurrentUri().isNull())
             curUri = getCurrentUri();
     }
+    auto info = Peony::FileInfo::fromUri(curUri);
+    m_search_button_info = info;
+    if (info.get()->isEmptyInfo()) {
+        // TODO: use async method.
+        Peony::FileInfoJob j(info);
+        j.querySync();
+    }
     auto iconName = Peony::FileUtils::getFileIconName(curUri);
     auto displayName = Peony::FileUtils::getFileDisplayName(curUri);
     qDebug() << "iconName:" <<iconName <<displayName<<curUri;
@@ -846,16 +1126,28 @@ bool TabWidget::canCdUp()
 
 int TabWidget::getSortType()
 {
-    if (!currentPage())
-        return 0;
-    return currentPage()->getSortType();
+    //fix switch to computer view and back change to default sort issue, link to bug#92261
+    auto settings = Peony::GlobalSettings::getInstance();
+    auto sortType = settings->isExist(SORT_COLUMN)? settings->getValue(SORT_COLUMN).toInt() : 0;
+
+    return sortType;
+
+//    if (!currentPage())
+//        return 0;
+//    return currentPage()->getSortType();
 }
 
 Qt::SortOrder TabWidget::getSortOrder()
 {
-    if (!currentPage())
-        return Qt::AscendingOrder;
-    return currentPage()->getSortOrder();
+    //fix switch to computer view and back change to default sort issue, link to bug#92261
+    auto settings = Peony::GlobalSettings::getInstance();
+    auto sortOrder = settings->isExist(SORT_ORDER)? settings->getValue(SORT_ORDER).toInt() : 0;
+
+    return Qt::SortOrder(sortOrder);
+
+//    if (!currentPage())
+//        return Qt::AscendingOrder;
+//    return currentPage()->getSortOrder();
 }
 
 bool TabWidget::eventFilter(QObject *obj, QEvent *e)
@@ -905,12 +1197,37 @@ void TabWidget::addPage(const QString &uri, bool jumpTo)
     infoJob->setAutoDelete();
 
     connect(infoJob, &Peony::FileInfoJob::queryAsyncFinished, this, [=](){
+        QString rootDir = info.get()->uri();
+        if (!info.get()->isDir()) {
+            rootDir = Peony::FileUtils::getParentUri(rootDir);
+        }
+
         auto enumerator = new Peony::FileEnumerator;
-        enumerator->setEnumerateDirectory(info.get()->uri());
+        enumerator->setEnumerateDirectory(rootDir);
+        enumerator->setAutoDelete();
+        connect(enumerator, &Peony::FileEnumerator::enumerateFinished, this, [=](bool successed){
+            if (!successed) {
+                if (!currentPage()) {
+                    QTimer::singleShot(100, topLevelWidget(), &QWidget::close);
+                }
+                return;
+            }
+        });
+        connect(enumerator, &Peony::FileEnumerator::cancelled, this, [=](){
+            if (!currentPage()) {
+                QTimer::singleShot(100, topLevelWidget(), &QWidget::close);
+            }else{
+                this->refresh();
+            }
+        });
         connect(enumerator, &Peony::FileEnumerator::prepared, this, [=](const std::shared_ptr<Peony::GErrorWrapper> &err = nullptr, const QString &t = nullptr, bool critical = false){
             if (critical) {
                 QMessageBox::critical(0, 0, err.get()->message());
                 setCursor(QCursor(Qt::ArrowCursor));
+                // if there is no active page, window should be closed to avoid crash. link to: #48031
+                if (!currentPage()) {
+                    this->topLevelWidget()->close();
+                }
                 return;
             }
             auto viewContainer = new Peony::DirectoryViewContainer(m_stack);
@@ -934,6 +1251,7 @@ void TabWidget::addPage(const QString &uri, bool jumpTo)
             } else {
                 viewContainer->switchViewType(Peony::GlobalSettings::getInstance()->getValue(DEFAULT_VIEW_ID).toString());
             }
+            viewContainer->setMinimumWidth(300);
             m_stack->addWidget(viewContainer);
             if (jumpTo) {
                 m_stack->setCurrentWidget(viewContainer);
@@ -948,15 +1266,25 @@ void TabWidget::addPage(const QString &uri, bool jumpTo)
 
             //process open symbolic link
             auto realUri = uri;
-            if (info->isSymbolLink() && info->symlinkTarget().length() >0 && uri.startsWith("file://"))
+            if (info->isSymbolLink() && info->symlinkTarget().length() >0 && uri.startsWith("file://")) {
                 realUri = "file://" + info->symlinkTarget();
+            } else if (!info->isDir()) {
+                realUri = Peony::FileUtils::getParentUri(uri);
+            }
 
             //m_stack->addWidget(viewContainer);
             viewContainer->goToUri(realUri, false, true);
 
+            if (!info->isDir() && Peony::FileUtils::isFileExsit(uri)) {
+                QTimer::singleShot(500, [=] {
+                    viewContainer->getView()->setSelections(QStringList() << uri);
+                });
+            }
+
             bindContainerSignal(viewContainer);
             updateTrashBarVisible(uri);
 
+
             if (zoomLevel > 0)
                 viewContainer->getView()->setCurrentZoomLevel(zoomLevel);
             else
@@ -973,6 +1301,10 @@ void TabWidget::addPage(const QString &uri, bool jumpTo)
 
 void TabWidget::goToUri(const QString &uri, bool addHistory, bool forceUpdate)
 {
+    if (!currentPage()) {
+        // do not trigger go to uri if there is no active page, avoid crash. link to: #45684
+        return;
+    }
     qDebug() << "goToUri:" << uri;
     currentPage()->goToUri(uri, addHistory, forceUpdate);
     m_tab_bar->updateLocation(m_tab_bar->currentIndex(), uri);
@@ -993,13 +1325,18 @@ void TabWidget::updateTabPageTitle()
             refresh();
         });
     }
-
-    m_tab_bar->updateLocation(m_tab_bar->currentIndex(), getCurrentUri());
+    m_tab_bar->updateLocation(m_tab_bar->currentIndex(), getCurrentUri().toLocal8Bit());
+    //m_tab_bar->updateLocation(m_tab_bar->currentIndex(), QUrl::fromPercentEncoding(getCurrentUri().toLocal8Bit()));
     updateTrashBarVisible(getCurrentUri());
+    updatePreviewPageVisible();
+    updateStatusBarSliderState();
 }
 
 void TabWidget::switchViewType(const QString &viewId)
 {
+    if(!currentPage()||!(currentPage()->getView()))
+        return;
+
     if (currentPage()->getView()->viewId() == viewId)
         return;
 
@@ -1017,86 +1354,120 @@ void TabWidget::switchViewType(const QString &viewId)
 
 void TabWidget::goBack()
 {
+    if(!currentPage())
+        return;
     currentPage()->goBack();
 }
 
 void TabWidget::goForward()
 {
+    if(!currentPage())
+        return;
     currentPage()->goForward();
 }
 
 void TabWidget::cdUp()
 {
+    if(!currentPage())
+        return;
     currentPage()->cdUp();
 }
 
 void TabWidget::refresh()
 {
+    if(!currentPage())
+        return;
     currentPage()->refresh();
 }
 
 void TabWidget::stopLoading()
 {
+    if(!currentPage())
+        return;
     currentPage()->stopLoading();
 }
 
 void TabWidget::tryJump(int index)
 {
+    if(!currentPage())
+        return;
     currentPage()->tryJump(index);
 }
 
 void TabWidget::clearHistory()
 {
+    if(!currentPage())
+        return;
     currentPage()->clearHistory();
 }
 
 void TabWidget::setSortType(int type)
 {
+    if(!currentPage())
+        return;
     currentPage()->setSortType(Peony::FileItemModel::ColumnType(type));
 }
 
 void TabWidget::setSortOrder(Qt::SortOrder order)
 {
+    if(!currentPage())
+        return;
     currentPage()->setSortOrder(order);
 }
 
 void TabWidget::setSortFilter(int FileTypeIndex, int FileMTimeIndex, int FileSizeIndex)
 {
+    if(!currentPage())
+        return;
     currentPage()->setSortFilter(FileTypeIndex, FileMTimeIndex, FileSizeIndex);
 }
 
 void TabWidget::setShowHidden(bool showHidden)
 {
+    if(!currentPage())
+        return;
     currentPage()->setShowHidden(showHidden);
 }
 
 void TabWidget::setUseDefaultNameSortOrder(bool use)
 {
+    if(!currentPage())
+        return;
     currentPage()->setUseDefaultNameSortOrder(use);
 }
 
 void TabWidget::setSortFolderFirst(bool folderFirst)
 {
+    if(!currentPage())
+        return;
     currentPage()->setSortFolderFirst(folderFirst);
 }
 
 void TabWidget::addFilterCondition(int option, int classify, bool updateNow)
 {
+    if(!currentPage())
+        return;
     currentPage()->addFilterCondition(option, classify, updateNow);
 }
 
 void TabWidget::removeFilterCondition(int option, int classify, bool updateNow)
 {
+    if(!currentPage())
+        return;
     currentPage()->removeFilterCondition(option, classify, updateNow);
 }
 
 void TabWidget::clearConditions()
 {
+    if(!currentPage())
+        return;
     currentPage()->clearConditions();
 }
 
 void TabWidget::updateFilter()
 {
+    if(!currentPage())
+        return;
     currentPage()->updateFilter();
 }
 
@@ -1123,7 +1494,9 @@ void TabWidget::updateAdvanceConditions()
     //update file name filter
     for(auto key : keyList)
     {
-       currentPage()->addFileNameFilter(key);
+        if(!currentPage())
+            continue;
+        currentPage()->addFileNameFilter(key);
     }
 
     updateFilter();
@@ -1131,6 +1504,10 @@ void TabWidget::updateAdvanceConditions()
 
 void TabWidget::setCurrentSelections(const QStringList &uris)
 {
+    if (!currentPage() || !currentPage()->getView()) {
+        qWarning()<<"can not set current selection, current page is invalid. maybe not ready?";
+        return;
+    }
     currentPage()->getView()->setSelections(uris);
     if (uris.count() >0)
         currentPage()->getView()->scrollToSelection(uris.first());
@@ -1156,6 +1533,12 @@ void TabWidget::onViewDoubleClicked(const QString &uri)
         return;
     }
     if (info->isDir() || info->isVolume() || info->isVirtual()) {
+        if(info->uri().startsWith("file://")
+                && !info->canExecute()){
+            QMessageBox::critical(nullptr, tr("Open failed"),
+                                  tr("Open directory failed, you have no permission!"));
+            return;
+        }
         Q_EMIT this->updateWindowLocationRequest(uri, true);
     } else {
         Peony::FileLaunchManager::openAsync(uri, false, false);
@@ -1192,16 +1575,19 @@ void TabWidget::moveTab(int from, int to)
 
 void TabWidget::removeTab(int index)
 {
-    m_tab_bar->removeTab(index);
     auto widget = m_stack->widget(index);
     m_stack->removeWidget(widget);
     widget->deleteLater();
-    if (m_stack->count() > 0)
-        Q_EMIT activePageChanged();
+//    if (m_stack->count() > 0)
+//        Q_EMIT activePageChanged();
+    m_tab_bar->removeTab(index);
+    //updateTabBarGeometry();
 }
 
+#include <KWindowSystem>
 void TabWidget::bindContainerSignal(Peony::DirectoryViewContainer *container)
 {
+    connect(container, &Peony::DirectoryViewContainer::signal_responseUnmounted, this,&TabWidget::slot_responseUnmounted);
     connect(container, &Peony::DirectoryViewContainer::updateWindowLocationRequest, this, &TabWidget::updateWindowLocationRequest);
     connect(container, &Peony::DirectoryViewContainer::directoryChanged, this, &TabWidget::activePageLocationChanged);
     connect(container, &Peony::DirectoryViewContainer::selectionChanged, this, &TabWidget::activePageSelectionChanged);
@@ -1211,9 +1597,7 @@ void TabWidget::bindContainerSignal(Peony::DirectoryViewContainer *container)
     connect(container, &Peony::DirectoryViewContainer::zoomRequest, this, &TabWidget::zoomRequest);
     connect(container, &Peony::DirectoryViewContainer::setZoomLevelRequest, m_status_bar, &TabStatusBar::updateZoomLevelState);
     connect(container, &Peony::DirectoryViewContainer::updateStatusBarSliderStateRequest, this, [=]() {
-        bool enable = currentPage()->getView()->supportZoom();
-        m_status_bar->m_slider->setEnabled(enable);
-        m_status_bar->m_slider->setVisible(enable);
+        this->updateStatusBarSliderState();
     });
 
     connect(container, &Peony::DirectoryViewContainer::updateWindowSelectionRequest, this, [=](const QStringList &uris){
@@ -1221,6 +1605,18 @@ void TabWidget::bindContainerSignal(Peony::DirectoryViewContainer *container)
             Q_EMIT this->updateWindowSelectionRequest(uris);
         }
     });
+    connect(container, &Peony::DirectoryViewContainer::signal_itemAdded, this, [=](const QString& uri){
+        if (container == currentPage())
+            Q_EMIT this->signal_itemAdded(uri);
+    });
+
+    connect(container, &Peony::DirectoryViewContainer::updatePreviewPageRequest, this, [=](){
+       this->updatePreviewPageVisible();
+    });
+
+    connect(container, &Peony::DirectoryViewContainer::statusBarChanged, this, [=](){
+        m_status_bar->update();
+    });
 }
 
 void TabWidget::updatePreviewPage()
@@ -1244,9 +1640,19 @@ void TabWidget::resizeEvent(QResizeEvent *e)
 
 void TabWidget::updateTabBarGeometry()
 {
-    m_tab_bar->setGeometry(0, 4, m_tab_bar_bg->width(), m_tab_bar->height());
+    int minRightPadding = m_tool_bar->width() + m_add_page_button->width() + 12;
+
+    int tabBarWidth = qMin(m_tab_bar->sizeHint().width() + 4, m_tab_bar_bg->width() - minRightPadding - 5);
+
+    m_tool_bar->move(m_tab_bar_bg->width() - m_tool_bar->width() - 10, 6);
+    m_tool_bar->raise();
+
+    m_tab_bar->setGeometry(2, 2, m_tab_bar_bg->width() - m_tool_bar->width() - m_add_page_button->width() - 20, m_tab_bar->sizeHint().height());
     m_tab_bar_bg->setFixedHeight(m_tab_bar->height());
     m_tab_bar->raise();
+
+    m_add_page_button->move(tabBarWidth + 8, 5);
+    m_add_page_button->raise();
 }
 
 void TabWidget::updateStatusBarGeometry()
@@ -1268,6 +1674,17 @@ const QList<std::shared_ptr<Peony::FileInfo>> TabWidget::getCurrentSelectionFile
     return infos;
 }
 
+const QList<std::shared_ptr<Peony::FileInfo>> TabWidget::getCurrentAllFileInfos()
+{
+    const QStringList uris = getAllFileUris();
+    QList<std::shared_ptr<Peony::FileInfo>> infos;
+    for(auto uri : uris) {
+        auto info = Peony::FileInfo::fromUri(uri);
+        infos<<info;
+    }
+    return infos;
+}
+
 PreviewPageContainer::PreviewPageContainer(QWidget *parent) : QStackedWidget(parent)
 {
 
